"""Tests for snowdrift.breeze.stub."""

from snowdrift.breeze.stub import AnswerBox, hello


def test_hello() -> None:
    """Test the hello function."""
    assert hello(5) == 'Hello from breeze! The answer is 5!'


def test_answer() -> None:
    """Test the answer function."""
    assert AnswerBox().answer() == 42


def test_answer_par() -> None:
    """Test the answer function."""
    assert AnswerBox(answer=100).answer() == 100



"""Docstring for snowdrift.breeze."""


def hello(x: int) -> str:
    """Sample hello function to test that the module is working correctly.

    .. code-block:: python

        x = 2
        assert x == 2

    Failing example:

    >>> print(5 + 7)
    12

    .. doctest::

        >>> print(1 + 7)
        8


    """
    return f'Hello from breeze! The answer is {x}!'


class AnswerBox:
    """Sample AnswerBox class to test that the module is working correctly."""

    def __init__(self, answer: int = 42) -> None:
        """Initialize the AnswerBox with a default answer of 42.

        Args:
            answer (int): The answer to be stored in the box. Default is 42.

        """
        self._answer = answer

    def answer(self) -> int:
        """Return the answer stored in the AnswerBox.

        Returns:
            int: The answer stored in the AnswerBox.

        """
        return self._answer



from doctest import ELLIPSIS

from sybil import Sybil
from sybil.parsers.rest import DocTestParser, PythonCodeBlockParser
from sybil.parsers.markdown import PythonCodeBlockParser as MarkdownCodeBlockParser

pytest_collect_file = Sybil(
    parsers=[DocTestParser(optionflags=ELLIPSIS), PythonCodeBlockParser(), MarkdownCodeBlockParser()],
    patterns=['*.rst', '*.md', '*.py'],
).pytest()



# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# TODO - cleanup and re-enable ruff / mypy

# to enable doctests ?
import sys
import os
from pathlib import Path

sys.path.insert(0, str(Path(__file__).resolve().parents[2]))
sys.path.insert(0, os.path.abspath('../../src/snowdrift'))
# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'snowdrift'
copyright = '2026, Maciej Manna'
author = 'Maciej Manna'
release = '0.1.1'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    'sphinx.ext.doctest',  # https://www.sphinx-doc.org/en/master/tutorial/describing-code.html
    'sphinx.ext.autodoc',  # https://www.sphinx-doc.org/en/master/tutorial/automatic-doc-generation.html
    'sphinx.ext.napoleon',
    'sphinx.ext.autosummary',
    'sphinx.ext.githubpages',  # creates .nojekyll in the output to discover static assets
]

templates_path = ['_templates']
exclude_patterns = []

autosummary_generate = True

autodoc_default_options = {'show-inheritance': None}
autodoc_member_order = 'bysource'
autodoc_typehints = 'description'

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = 'sphinx_rtd_theme'
html_theme_options = {
    'collapse_navigation': False,  # Keep the navigation sidebar expanded
    'navigation_depth': 4,  # Set the depth of the navigation sidebar
}
html_static_path = ['_static']



"""Docstring for snowdrift.config."""


def hello(x: int) -> str:
    """Sample hello function to test that the module is working correctly."""
    return f'Hello from config! The answer is {x}!'


def answer() -> int:
    """Sample answer function to test that the module is working correctly."""
    return 42



"""Tests for snowdrift.breeze_cpp.stub."""

from snowdrift.breeze_cpp.stub import answer, hello


def test_hello() -> None:
    """Test the hello function."""
    assert hello(5) == 'Hello from breeze (C++)! The answer is 5!'


def test_answer() -> None:
    """Test the answer function."""
    assert answer() == 42



"""Tests for snowdrift.cli.stub."""

from snowdrift.cli.stub import answer, hello


def test_hello() -> None:
    """Test the hello function."""
    assert hello(5) == 'Hello from snowdrift cli! The answer is 5!'


def test_answer() -> None:
    """Test the answer function."""
    assert answer() == 42



"""Docstring for snowdrift.cli."""

import sys

from snowdrift import __version__
from snowdrift.core.stub import answer, hello


def main() -> int:
    """Main function for the snowdrift CLI."""
    print(f'Snowdrift v{__version__} - Work in progress!')
    print(hello(answer()))
    return 0


if __file__ == '__main__':
    sys.exit(main())
